@@ -1,29 +1,26 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: freetext.tcl,v 1.11 1998/11/17 21:05:35 jfontain Exp $}
+set rcsId {$Id: freetext.tcl,v 1.13 1998/11/29 13:46:39 jfontain Exp $}
 
 class freeText {
 
     proc freeText {this parentPath args} composite {
         [new text $parentPath -font $font::(mediumNormal) -wrap word -borderwidth 0 -highlightthickness 0] $args
     } viewer {} {
-        set freeText::($this,drop) [new dropSite\
-            -path $widget::($this,path) -formats DATACELLS -command "viewer::view $this \$dragSite::data(DATACELLS)"\
-        ]
+        viewer::setupDropSite $this $widget::($this,path)                                            ;# allow dropping of data cells
         set freeText::($this,labels) {}
         composite::complete $this
     }
 
     proc ~freeText {this} {
-        delete $freeText::($this,drop)
         if {[info exists freeText::($this,drag)]} {
             delete $freeText::($this,drag)
         }
+        eval delete $freeText::($this,labels)
         if {[info exists freeText::($this,selector)]} {
             delete $freeText::($this,selector)
         }
-        eval delete $freeText::($this,labels)
         if {[string length $composite::($this,-deletecommand)]>0} {
             uplevel #0 $composite::($this,-deletecommand)                                   ;# always invoke command at global level
         }
