@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: sumtable.tcl,v 1.13 1998/11/17 21:05:35 jfontain Exp $}
+set rcsId {$Id: sumtable.tcl,v 1.15 1998/11/29 13:47:58 jfontain Exp $}
 
 class summaryTable {
 
@@ -31,9 +31,7 @@ class summaryTable {
         ]
         ### hack: drag and drop code should be separated from dataTable which should provide a selected member procedure ###
         # allow dropping of data cells ### use same path as drag path to avoid drops in table from table ###
-        set summaryTable::($this,drop) [new dropSite\
-            -path $dataTable::($table,tablePath) -formats DATACELLS -command "viewer::view $this \$dragSite::data(DATACELLS)"\
-        ]
+        viewer::setupDropSite $this $dataTable::($table,tablePath)
         if {$composite::($this,-draggable)} {
             # extend data table drag capabilities ### hack ### also eventually allow row selection only instead of cells ###
             dragSite::provide $dataTable::($table,drag) OBJECTS "summaryTable::dragData $this"
@@ -49,7 +47,7 @@ class summaryTable {
         foreach name [array names {} $this,rowLastWish,*] {                        ;# delete remaining last wishes, one for each row
             delete $summaryTable::($name)                                                               ;# which in turn deletes row
         }
-        delete $summaryTable::($this,dataTable) $summaryTable::($this,drop)
+        delete $summaryTable::($this,dataTable)
         catch {unset ${this}cellRow}
         incr ${dataName}(updates)                                        ;# so related viewers can eventually show disappeared cells
         unset $dataName
@@ -174,8 +172,8 @@ class summaryTable {
         foreach row [array names selected] {
             lappend lastWishes $summaryTable::($this,rowLastWish,$row)
         }
-        if {([llength $lastWishes]==[array size ${this}cellRow])||([llength $lastWishes]==0)} {
-            return $this                                                 ;# self destruct if all rows are selected or no rows remain
+        if {[llength $lastWishes]==0} {
+            return $this                                                                          ;# self destruct if no rows remain
         } else {
             return $lastWishes
         }
